@@ -1,8 +1,10 @@
 alias mCSText XmCSText
+alias mCSTextReplace XmCSTextReplace
 alias mScrolledCSText XmScrolledCSText
 alias mCSText XmCSText
 alias mComboBox XmComboBox
 alias mContainer XmContainer
 alias mIconGadget XmIconGadget
 alias mNotebook XmNotebook
+alias mScaleSetTicks XmScaleSetTicks
 alias mSpinBox XmSpinBox
